@@ -8,31 +8,32 @@ OC.L10N.register(
     "Current" : "Mövcud",
     "Completed" : "Bitmişdir",
     "Tasks" : "Tapşırıqlar",
-    "Visibility of Smart Collections" : "Ağıllı yiğımların görünməsi",
     "Hidden" : "Gizli",
     "Visible" : "Görünən",
     "Automatic" : "Avtomatik",
+    "Visibility of Smart Collections" : "Ağıllı yiğımların görünməsi",
     "Can edit" : "Can edit",
+    "An empty name is not allowed." : "Boş ada izin verilmir.",
     "Edit" : "Dəyişiklik et",
     "Export" : "Çıxarış",
     "Delete" : "Sil",
     "Unshare" : "Paylaşımı durdur",
-    "An empty name is not allowed." : "Boş ada izin verilmir.",
     "Name" : "Ad",
     "Deleted" : "Silinib",
     "Restore" : "Geri qaytar",
     "Delete permanently" : "Həmişəlik sil",
     "Cancel" : "Dayandır",
+    "Email" : "Email",
     "Close" : "Bağla",
     "Priority" : "Prioritet",
+    "Tags" : "Işarələr",
     "Manually" : "Əl ilə",
     "_%n Completed Task_::_%n Completed Tasks_" : ["\"%s\" Bitmiş Tapşırıqlar","Completed Tasks"],
     "Tomorrow" : "Sabah",
-    "Details" : "Detallar",
-    "Notes" : "Qeydlər",
-    "Repeat" : "Təkrar",
     "Task not found!" : "Tapşırıq tapılmadı!",
     "Set start date" : "Başlanğıc tarixini işə sal",
-    "Set due date" : "Vaxtı təyin et"
+    "Set due date" : "Vaxtı təyin et",
+    "Details" : "Detallar",
+    "Notes" : "Qeydlər"
 },
 "nplurals=2; plural=(n != 1);");
