@@ -16,9 +16,9 @@ OC.L10N.register(
     "Name" : "Ime",
     "Restore" : "Obnovi",
     "Cancel" : "Odustani",
+    "Email" : "E-pošta",
     "Close" : "Zatvori",
     "Tomorrow" : "Sutra",
-    "Notes" : "Notes",
-    "Repeat" : "Ponovi"
+    "Notes" : "Notes"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
