@@ -7,11 +7,13 @@ OC.L10N.register(
     "Edit" : "Deasaich",
     "Delete" : "Sguab às",
     "Unshare" : "Na co-roinn tuilleadh",
+    "Empty trash bin" : "Falamhaich an sgudal",
     "Name" : "Ainm",
     "Deleted" : "Chaidh a sguabadh às",
-    "Empty trash bin" : "Falamhaich an sgudal",
     "Cancel" : "Sguir dheth",
+    "Email" : "Post-d",
     "Close" : "Dùin",
+    "Tags" : "Tagaichean",
     "Details" : "Mion-fhiosrachadh",
     "Notes" : "Nòtaichean"
 },
