@@ -10,29 +10,25 @@ OC.L10N.register(
     "Completed" : "Završeno",
     "Tasks" : "Zadaci",
     "The Tasks app for Nextcloud" : "Aplikacija Zadaci za Nextcloud",
-    "Default list" : "Zadani popis",
-    "Visibility of Smart Collections" : "Vidljivost pametnih zbirki",
     "Hidden" : "Skriveno",
     "Visible" : "Vidljivo",
     "Automatic" : "Automatsko",
+    "Default list" : "Zadani popis",
+    "Visibility of Smart Collections" : "Vidljivost pametnih zbirki",
     "Share with users or groups" : "Dijelite s korisnicima ili grupama",
     "No users or groups" : "Nema korisnika ili grupa",
-    "Can edit" : "Uređivanje moguće",
-    "Unshare with {displayName}" : "Prekid dijeljenja s {displayName}",
     "Unable to delete the share." : "Nije moguće izbrisati dijeljenje.",
     "Unable to change permissions." : "Nije moguće promijeniti dopuštenja.",
-    "Edit" : "Uredi",
-    "Copy private link" : "Kopiraj privatnu poveznicu",
-    "Copied" : "Kopirano",
-    "Cannot copy" : "Nije moguće kopirati",
-    "Export" : "Izvoz",
-    "Delete" : "Izbriši",
-    "Unshare" : "Prestani dijeliti",
-    "List name" : "Naziv popisa",
+    "Can edit" : "Uređivanje moguće",
+    "Unshare with {displayName}" : "Prekid dijeljenja s {displayName}",
     "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Time će se izbrisati kalendar „{calendar}” i svi pripadajući događaji i zadaci.",
     "This will unshare the calendar \"{calendar}\"." : "Time će se prestati dijeliti kalendar „{calendar}“.",
     "This will delete the list \"{list}\" and all corresponding tasks." : "Time će se izbrisati popis „{list}” i svi pripadajući zadaci.",
     "This will unshare the list \"{list}\"." : "Time će se prestati dijeliti popis „{list}“.",
+    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Brisanje kalendara za {countdown} sekundu","Brisanje kalendara za {countdown} sekundi","Brisanje kalendara za {countdown} sekundi"],
+    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Prekid dijeljenja kalendara za {countdown} sekundu","Prekid dijeljenja kalendara za {countdown} sekundi","Prekid dijeljenja kalendara za {countdown} sekundi"],
+    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Brisanje popisa za {countdown} sekundu","Brisanje popisa za {countdown} sekunde","Brisanje popisa za {countdown} sekundi"],
+    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Prestanak dijeljenja popisa za {countdown} sekundu","Prestanak dijeljenja popisa za {countdown} sekunde","Prestanak dijeljenja popisa za {countdown} sekundi"],
     "Calendar link copied to clipboard." : "Poveznica kalendara kopirana je u međuspremnik.",
     "List link copied to clipboard." : "Poveznica popisa kopirana je u međuspremnik.",
     "Calendar link could not be copied to clipboard." : "Poveznica kalendara nije kopirana u međuspremnik.",
@@ -41,11 +37,21 @@ OC.L10N.register(
     "An empty name is not allowed." : "Prazan naziv nije dopušten.",
     "An error occurred, unable to delete the calendar." : "Došlo je do pogreške, nije moguće izbrisati kalendar.",
     "An error occurred, unable to delete the list." : "Došlo je do pogreške, nije moguće izbrisati popis.",
-    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Brisanje kalendara za {countdown} sekundu","Brisanje kalendara za {countdown} sekundi","Brisanje kalendara za {countdown} sekundi"],
-    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Prekid dijeljenja kalendara za {countdown} sekundu","Prekid dijeljenja kalendara za {countdown} sekundi","Prekid dijeljenja kalendara za {countdown} sekundi"],
-    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Brisanje popisa za {countdown} sekundu","Brisanje popisa za {countdown} sekunde","Brisanje popisa za {countdown} sekundi"],
-    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Prestanak dijeljenja popisa za {countdown} sekundu","Prestanak dijeljenja popisa za {countdown} sekunde","Prestanak dijeljenja popisa za {countdown} sekundi"],
-    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Dijeljeno s {num} entitetom","Dijeljeno s {num} entiteta","Dijeljeno s {num} entiteta"],
+    "Edit" : "Uredi",
+    "Copy private link" : "Kopiraj privatnu poveznicu",
+    "Copied" : "Kopirano",
+    "Cannot copy" : "Nije moguće kopirati",
+    "Export" : "Izvoz",
+    "Delete" : "Izbriši",
+    "Unshare" : "Prestani dijeliti",
+    "List name" : "Naziv popisa",
+    "Untitled task" : "Zadatak bez naslova",
+    "Untitled event" : "Događaj bez naslova",
+    "Untitled item" : "Stavka bez naslova",
+    "Could not load deleted calendars and objects" : "Učitavanje izbrisanih kalendara i objekata nije uspjelo",
+    "Could not restore calendar or event" : "Vraćanje kalendara ili događaja nije uspjelo",
+    "Do you really want to empty the trash bin?" : "Želite li zaista isprazniti kantu za smeće?",
+    "Empty trash bin" : "Isprazni kantu za smeće",
     "Trash bin" : "Kanta za smeće",
     "Loading deleted calendars, tasks and events." : "Učitavanje izbrisanih kalendara, zadataka i događaja.",
     "You do not have any deleted calendars, tasks or events." : "Nemate izbrisanih kalendara, zadataka ili događaja.",
@@ -53,14 +59,21 @@ OC.L10N.register(
     "Deleted" : "Izbrisano",
     "Restore" : "Vrati",
     "Delete permanently" : "Trajno izbrišite",
-    "Empty trash bin" : "Isprazni kantu za smeće",
-    "Untitled task" : "Zadatak bez naslova",
-    "Untitled event" : "Događaj bez naslova",
-    "Untitled item" : "Stavka bez naslova",
-    "Could not load deleted calendars and objects" : "Učitavanje izbrisanih kalendara i objekata nije uspjelo",
-    "Could not restore calendar or event" : "Vraćanje kalendara ili događaja nije uspjelo",
-    "Do you really want to empty the trash bin?" : "Želite li zaista isprazniti kantu za smeće?",
     "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Elementi u kanti za smeće brišu se nakon {numDays} dan","Elementi u kanti za smeće brišu se nakon {numDays} dana","Elementi u kanti za smeće brišu se nakon {numDays} dana"],
+    "Cancel" : "Odustani",
+    "Email" : "E-pošta",
+    "Audio notification" : "Zvučna obavijest",
+    "Other notification" : "Druga obavijest",
+    "Edit time" : "Uredi vrijeme",
+    "Remove reminder" : "Ukloni podsjetnik",
+    "Add reminder" : "Dodaj podsjetnik",
+    "Go back" : "Natrag",
+    "before at" : "prije u",
+    "_second_::_seconds_" : ["sekunda","sekundi","sekundi"],
+    "_minute_::_minutes_" : ["minuta","minuta","minuta"],
+    "_hour_::_hours_" : ["sat","sati","sati"],
+    "_day_::_days_" : ["dan","dana","dana"],
+    "_week_::_weeks_" : ["tjedan","tjedana","tjedana"],
     "Select a calendar" : "Odaberi kalendar",
     "Set date" : "Postavi datum",
     "Set time" : "Postavi vrijeme",
@@ -70,7 +83,6 @@ OC.L10N.register(
     "Delete value" : "Izbriši vrijednost",
     "Add this as a new tag" : "Dodaj kao novu oznaku",
     "No tag available. Create one!" : "Nema dostupnih oznaka. Stvorite je!",
-    "Cancel" : "Odustani",
     "Close" : "Zatvori",
     "Delete all completed tasks." : "Izbriši sve završene zadatke.",
     "Delete completed tasks." : "Izbriši završene zadatke.",
@@ -84,7 +96,6 @@ OC.L10N.register(
     "Add a task due today to \"{calendar}\"…" : "Dodajte zadatak za danas u „{calendar}”...",
     "Add a current task to \"{calendar}\"…" : "Dodaj trenutni zadatak u „{calendar}”...",
     "Add a task to \"{calendar}\"…" : "Dodajte zadatak u „{calendar}”...",
-    "Change sort order" : "Promijeni redoslijed razvrstavanja",
     "Relevance" : "Važnost",
     "Sort by completed state, due date, priority, start date and summary." : "Razvrstaj prema stanju, datumu dospijeća, prioritetu, datumu početka i sažetku.",
     "Start date" : "Datum početka",
@@ -96,19 +107,10 @@ OC.L10N.register(
     "Sort by priority and summary." : "Razvrstaj prema prioritetu i sažetku.",
     "Alphabetically" : "Abecedno",
     "Sort by summary and priority." : "Razvrstaj prema sažetku i prioritetu.",
+    "Tags" : "Oznake",
     "Manually" : "Ručno",
     "Sort by manual order." : "Razvrstaj ručno.",
-    "Task has hidden subtasks" : "Zadatak ima skrivene podzadatke",
-    "Task is pinned" : "Zadatak je prikvačen",
-    "Task has a note" : "Zadatak ima bilješku",
-    "{complete} % completed" : "Završeno {complete} %",
-    "Add subtask" : "Dodaj podzadatak",
-    "Show subtasks" : "Prikaži podzadatke",
-    "Hide subtasks" : "Sakrij podzadatke",
-    "Show closed subtasks" : "Prikaži zatvorene podzadatke",
-    "Hide closed subtasks" : "Sakrij zatvorene podzadatke",
-    "Delete task" : "Izbriši zadatak",
-    "Toggle starred" : "Uključi/isključi zvjezdicu",
+    "Change sort order" : "Promijeni redoslijed razvrstavanja",
     "[Yesterday]" : "[Jučer]",
     "[Today]" : "[Danas]",
     "[Tomorrow]" : "[Sutra]",
@@ -124,28 +126,28 @@ OC.L10N.register(
     "[Completed tomorrow at] LT" : "[Završeno sutra u] LT",
     "[Completed] L [at] LT" : "[Završeno] L [u] LT",
     "Add a subtask to \"{task}\"…" : "Dodaj podzadatak u „{task}”...",
+    "Task has hidden subtasks" : "Zadatak ima skrivene podzadatke",
+    "Task is pinned" : "Zadatak je prikvačen",
+    "Task has a note" : "Zadatak ima bilješku",
+    "{complete} % completed" : "Završeno {complete} %",
+    "Add subtask" : "Dodaj podzadatak",
+    "Show subtasks" : "Prikaži podzadatke",
+    "Hide subtasks" : "Sakrij podzadatke",
+    "Show closed subtasks" : "Prikaži zatvorene podzadatke",
+    "Hide closed subtasks" : "Sakrij zatvorene podzadatke",
+    "Delete task" : "Izbriši zadatak",
+    "Toggle starred" : "Uključi/isključi zvjezdicu",
     "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Brisanje zadatka za {countdown} sekundu","Brisanje zadatka za {countdown} sekunde","Brisanje zadatka za {countdown} sekundi"],
     "Task is completed" : "Zadatak je završen",
+    "\"{task}\" was added to \"{calendar}\"" : "„{task}“ je dodano u „{calendar}“",
     "Create a new task" : "Stvori novi zadatak",
     "Task summary" : "Sažetak zadatka",
     "Create task" : "Stvori zadatak",
     "Creating the new task…" : "Stvaranje novog zadatka...",
     "Open task" : "Otvori zadatak",
-    "\"{task}\" was added to \"{calendar}\"" : "„{task}“ je dodano u „{calendar}“",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n završeni zadatak","%n završenih zadataka","%n završenih zadataka"],
     "Tomorrow" : "Sutra",
     "Add List…" : "Dodaj popis…",
-    "All day" : "Cijeli dan",
-    "Unpin" : "Otkvači",
-    "Pin" : "Prikvači",
-    "Show in Calendar" : "Prikaži u kalendaru",
-    "Details" : "Pojedinosti",
-    "Select a classification" : "Odaberi klasifikaciju",
-    "Select a status" : "Odaberi status",
-    "Select tags" : "Odaberite oznake",
-    "Notes" : "Bilješke",
-    "Reminders" : "Podsjetnici",
-    "Repeat" : "Ponovi",
     "When shared show full event" : "Kada se dijeli, prikaži cijeli događaj",
     "When shared show only busy" : "Kada se dijeli, prikaži samo zauzeto",
     "When shared hide this event" : "Kada se dijeli, sakrij događaj",
@@ -175,9 +177,15 @@ OC.L10N.register(
     "Priority {priority}: high" : "Prioritet {priority}: visok",
     "No priority assigned" : "Nije dodijeljen prioritet",
     "{percent} % completed" : "Završeno {percent} %",
-    "No upcoming tasks" : "Nema nadolazećih zadataka",
-    "upcoming tasks" : "nadolazeći zadaci",
-    "No tasks today" : "Danas nema zadataka",
+    "All day" : "Cijeli dan",
+    "Unpin" : "Otkvači",
+    "Pin" : "Prikvači",
+    "Show in Calendar" : "Prikaži u kalendaru",
+    "Details" : "Pojedinosti",
+    "Select a classification" : "Odaberi klasifikaciju",
+    "Select a status" : "Odaberi status",
+    "Select tags" : "Odaberite oznake",
+    "Notes" : "Bilješke",
     "Mark as done" : "Označi kao završeno",
     "No due date assigned" : "Nema dodijeljenog datuma dospijeća",
     "[Due yesterday]" : "[Trebao je biti završen jučer]",
@@ -188,6 +196,9 @@ OC.L10N.register(
     "[Due today at] LT" : "[Treba završiti danas u] LT",
     "[Due tomorrow at] LT" : "[Treba završiti sutra u] LT",
     "[Due] L [at] LT" : "[Treba biti završen] L [u] LT",
+    "No upcoming tasks" : "Nema nadolazećih zadataka",
+    "upcoming tasks" : "nadolazeći zadaci",
+    "No tasks today" : "Danas nema zadataka",
     "Successfully created the task." : "Zadatak je uspješno stvoren.",
     "Could not delete the task." : "Zadatak nije moguće izbrisati.",
     "Synchronizing to the server." : "Sinkronizacija s poslužiteljem.",
