@@ -9,14 +9,18 @@ OC.L10N.register(
     "Completed" : "Selesai",
     "Tasks" : "Tugas",
     "The Tasks app for Nextcloud" : "Aplikasi Tugas untuk Nextcloud",
-    "Visibility of Smart Collections" : "Visibilitas Koleksi Cerdas",
     "Hidden" : "Sembunyi",
     "Visible" : "Tampak",
     "Automatic" : "Otomatis",
+    "Visibility of Smart Collections" : "Visibilitas Koleksi Cerdas",
     "Share with users or groups" : "Bagi dengan pengguna atau grup",
     "No users or groups" : "Tidak ada pengguna atau grup",
     "Can edit" : "Can edit",
     "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
+    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
+    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
+    "An empty name is not allowed." : "Nama kosong tidak diperbolehkan.",
+    "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
     "Edit" : "Sunting",
     "Copy private link" : "Salin tautan privat",
     "Copied" : "Tersalin",
@@ -24,16 +28,6 @@ OC.L10N.register(
     "Delete" : "Hapus",
     "Unshare" : "Batalkan berbagi",
     "List name" : "Nama daftar",
-    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
-    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
-    "An empty name is not allowed." : "Nama kosong tidak diperbolehkan.",
-    "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
-    "Trash bin" : "Keranjang sampah",
-    "Name" : "Nama",
-    "Deleted" : "Dihapus",
-    "Restore" : "Pulihkan",
-    "Delete permanently" : "Hapus secara permanen",
-    "Empty trash bin" : "Kosongkan tempat sampah",
     "Untitled task" : "Tugas tanpa judul",
     "Untitled event" : "Acara tanpa judul",
     "Untitled item" : "Item tanpa judul",
@@ -41,23 +35,41 @@ OC.L10N.register(
     "Could not load deleted calendars and objects" : "Tidak dapat memuat kalender dan objek yang dihapus",
     "Could not restore calendar or event" : "Tidak dapat memulihkan kalender atau acara",
     "Do you really want to empty the trash bin?" : "Apakah Anda benar-benar ingin mengosongkan keranjang sampah?",
+    "Empty trash bin" : "Kosongkan tempat sampah",
+    "Trash bin" : "Keranjang sampah",
+    "Name" : "Nama",
+    "Deleted" : "Dihapus",
+    "Restore" : "Pulihkan",
+    "Delete permanently" : "Hapus secara permanen",
     "Cancel" : "Batal",
+    "Notification" : "Notifikasi",
+    "Email" : "Email",
+    "Audio notification" : "Notifikasi audio",
+    "Other notification" : "Notifikasi lain",
+    "Edit time" : "Edit waktu",
+    "Remove reminder" : "Buang pengingat",
+    "Go back" : "Kembali",
+    "_second_::_seconds_" : ["detik"],
+    "_minute_::_minutes_" : ["menit"],
+    "_hour_::_hours_" : ["jam"],
+    "_day_::_days_" : ["hari"],
+    "_week_::_weeks_" : ["minggu"],
     "Close" : "Tutup",
     "Select tags to filter by" : "Pilih tag untuk disaring",
     "Due date" : "Tenggat",
     "Last modified" : "Terakhir diubah",
     "Alphabetically" : "Berdasarkan abjad",
+    "Tags" : "Tag",
     "[Today]" : "[Hari ini]",
+    "Delete task" : "Hapus tugas",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tugas Diselesaikan"],
     "Tomorrow" : "Besok",
-    "All day" : "Sepanjang hari",
-    "Details" : "Detail",
-    "Notes" : "Catatan",
-    "Reminders" : "Pengingat",
-    "Repeat" : "Ulang",
     "Task not found!" : "Tugas tidak ditemukan!",
     "Set start date" : "Atur tanggal mulai",
     "Set due date" : "Atur tanggal jatuh tempo",
+    "All day" : "Sepanjang hari",
+    "Details" : "Detail",
+    "Notes" : "Catatan",
     "Mark as done" : "Tandai sebagai selesai",
     "An error occurred" : "Terjadi kesalahan",
     "[Starts today]" : "[Dimulai hari ini]"
