@@ -67,9 +67,9 @@ OC.L10N.register(
     "_week_::_weeks_" : ["週"],
     "Select a calendar" : "カレンダーを選択",
     "Click here to add a note." : "クリックしてノートを追加",
-    "Create new tasks" : "新しいタスクを作成する",
-    "Create tasks" : "タスクを作成する",
-    "Creating new tasks…" : "新しいタスクを作成する",
+    "Create new tasks" : "新規タスクを作成",
+    "Create tasks" : "タスクを作成",
+    "Creating new tasks…" : "新規タスクを作成中...",
     "Close" : "閉じる",
     "Delete all completed tasks." : "全ての完了したタスクを削除",
     "Delete completed tasks." : "完了したタスクを削除",
@@ -137,6 +137,7 @@ OC.L10N.register(
     "Details" : "詳細",
     "Select a classification" : "分類を選択",
     "Select a status" : "ステータスを選択",
+    "Set a location" : "場所を設定する",
     "Select tags" : "タグを選択",
     "Notes" : "ノート",
     "Mark as done" : "完了としてマーク",
@@ -144,6 +145,7 @@ OC.L10N.register(
     "[Due today]" : "[今日まで]",
     "[Due tomorrow]" : "[明日まで]",
     "[Due] L" : "L [まで]",
+    "No upcoming tasks" : "今後のタスクはありません",
     "upcoming tasks" : "今後のタスク",
     "No tasks today" : "今日はタスクなし",
     "Successfully created the task." : "タスクの作成に成功しました",
@@ -153,6 +155,7 @@ OC.L10N.register(
     "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "サーバー上でタスクが変更されたため、タスクを更新できませんでした。 クリックして更新してください。ローカルの変更は破棄されます。",
     "Could not update the task." : "タスクを更新できませんでした",
     "Successfully updated the task." : "タスクのアップデートに成功しました",
+    "Task successfully moved to new calendar." : "タスクは新しいカレンダーに正常に移動されました。",
     "An error occurred" : "エラーが発生しました",
     "Create a task" : "タスクを作成する",
     "Message from {author} in {conversationName}" : "{conversationName} で {author} からのメッセージ",
