@@ -13,21 +13,21 @@ OC.L10N.register(
     "Export" : "Eksporter",
     "Delete" : "Slett",
     "Unshare" : "Fjern deling",
+    "Empty trash bin" : "Tøm søppel korg",
     "Name" : "Namn",
     "Deleted" : "Sletta",
     "Restore" : "Gjenopprett",
     "Delete permanently" : "Slett for godt",
-    "Empty trash bin" : "Tøm søppel korg",
     "Cancel" : "Avbryt",
+    "Email" : "Epost",
     "Close" : "Lukk",
     "Last modified" : "Siste endra",
-    "Details" : "Detaljar",
-    "Notes" : "Notat",
-    "Reminders" : "Påminningar",
-    "Repeat" : "Gjenta",
+    "Tags" : "Emneord",
     "When shared show full event" : "Når delt, vis heile hendinga",
     "When shared show only busy" : "Når delt, vis berre oppteken",
     "When shared hide this event" : "Når delt, gøym denne hendinga",
+    "Details" : "Detaljar",
+    "Notes" : "Notat",
     "An error occurred" : "Det oppstod ein feil"
 },
 "nplurals=2; plural=(n != 1);");
