@@ -2,18 +2,21 @@ OC.L10N.register(
     "tasks",
     {
     "Today" : "Today",
+    "All" : "Sve",
     "Current" : "Tekuće",
     "Completed" : "Završeno",
     "Can edit" : "Can edit",
     "Edit" : "Uredi",
     "Delete" : "Delete",
     "Unshare" : "Ukini deljenje",
+    "Empty trash bin" : "Isprazni kantu",
     "Name" : "Ime",
     "Deleted" : "Obrisano",
     "Delete permanently" : "Obriši zauvek",
     "Cancel" : "Cancel",
     "Close" : "Zatvori",
     "Due date" : "Rok",
+    "Tags" : "Oznake",
     "Details" : "Detalji",
     "Notes" : "Beleške"
 },
