@@ -17,9 +17,10 @@ OC.L10N.register(
     "Restore" : "மீட்டெடு",
     "Delete permanently" : "நிரந்தரமாக நீக்கவும்",
     "Cancel" : "இரத்து செய்க",
+    "Email" : "மின்னஞ்சல்",
     "Close" : "மூடுக",
+    "Tags" : "சீட்டுகள்",
     "Details" : "விவரங்கள்",
-    "Notes" : "குறிப்புகள்",
-    "Repeat" : "மீண்டும்"
+    "Notes" : "குறிப்புகள்"
 },
 "nplurals=2; plural=(n != 1);");
