@@ -14,10 +14,15 @@ OC.L10N.register(
     "Automatic" : "Tự động",
     "Share with users or groups" : "Chia sẽ với người dùng hoặc nhóm",
     "No users or groups" : "Không có người dùng hay nhóm",
-    "Can edit" : "Có thể chỉnh sửa",
-    "Unshare with {displayName}" : "Gỡ chia sẻ với {displayName}",
     "Unable to delete the share." : "Không thể xóa chia sẻ.",
     "Unable to change permissions." : "Không thể thay đổi quyền hạn.",
+    "Can edit" : "Có thể chỉnh sửa",
+    "Unshare with {displayName}" : "Gỡ chia sẻ với {displayName}",
+    "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
+    "Calendar link could not be copied to clipboard." : "liên kết của lịch không thể sao chép vào bảng tạm.",
+    "The name \"{calendar}\" is already used." : "Tên \"{calendar}\" đã được sử dụng.",
+    "An empty name is not allowed." : "Để trống tên không được cho phép.",
+    "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
     "Edit" : "Sửa",
     "Copy private link" : "Sao chép liên kết riêng tư",
     "Copied" : "Đã sao chép",
@@ -25,24 +30,33 @@ OC.L10N.register(
     "Delete" : "Xóa",
     "Unshare" : "Bỏ chia sẽ",
     "List name" : "Danh sách tên",
-    "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
-    "Calendar link could not be copied to clipboard." : "liên kết của lịch không thể sao chép vào bảng tạm.",
-    "The name \"{calendar}\" is already used." : "Tên \"{calendar}\" đã được sử dụng.",
-    "An empty name is not allowed." : "Để trống tên không được cho phép.",
-    "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
-    "Trash bin" : "Thùng rác",
-    "Name" : "Tên",
-    "Deleted" : "Đã xoá",
-    "Restore" : "Khôi phục",
-    "Delete permanently" : "Xoá vĩnh viễn",
-    "Empty trash bin" : "Dọn thùng rác",
     "Untitled task" : "Nhiệm vụ không tiêu đề",
     "Untitled event" : "Sự kiện không tiêu đề",
     "Unknown calendar" : "Lịch không rõ nguồn",
     "Could not load deleted calendars and objects" : "Không thể hiển thị lịch hoặc các đối tượng đã xoá",
     "Could not restore calendar or event" : "Không thể khôi phục lịch hoặc sự kiện",
     "Do you really want to empty the trash bin?" : "Bạn có chắc là muốn dọn sạch thùng rác hay không?",
+    "Empty trash bin" : "Dọn thùng rác",
+    "Trash bin" : "Thùng rác",
+    "Name" : "Tên",
+    "Deleted" : "Đã xoá",
+    "Restore" : "Khôi phục",
+    "Delete permanently" : "Xoá vĩnh viễn",
     "Cancel" : "Hủy",
+    "Notification" : "Thông báo",
+    "Email" : "Thư điện tử",
+    "Audio notification" : "Thông báo âm thanh",
+    "Other notification" : "Các thông báo khác",
+    "Edit time" : "Chỉnh sửa thời gian",
+    "Remove reminder" : "Gỡ bỏ lịch nhắc hẹn",
+    "Add reminder" : "Thêm vào nhắc hẹn",
+    "Go back" : "Quay lại",
+    "before at" : "trước lúc",
+    "_second_::_seconds_" : ["giây"],
+    "_minute_::_minutes_" : ["phút"],
+    "_hour_::_hours_" : ["giờ"],
+    "_day_::_days_" : ["ngày"],
+    "_week_::_weeks_" : ["tuần"],
     "Close" : "Đóng",
     "No errors" : "Không có lỗi",
     "Open your browser console for more details" : "Mở trong trình duyệt để biết thêm chi tiết",
@@ -50,22 +64,21 @@ OC.L10N.register(
     "Due date" : "Thời hạn",
     "Last modified" : "Lần cuối chỉnh sửa",
     "Alphabetically" : "Theo bảng chữ cái",
-    "Delete task" : "Xóa nhiệm vụ",
+    "Tags" : "Nhãn",
     "[Yesterday]" : "[Hôm qua]",
     "[Today]" : "[Hôm nay]",
     "[Tomorrow]" : "[Ngày mai]",
+    "Delete task" : "Xóa nhiệm vụ",
     "Tomorrow" : "Ngày mai",
     "Add List…" : "Thêm vào danh sách…",
-    "All day" : "Cả ngày",
-    "Details" : "Chi tiết",
-    "Select tags" : "Chọn một thẻ",
-    "Notes" : "Ghi chú",
-    "Reminders" : "Nhắc nhở",
-    "Repeat" : "Lặp lại",
     "When shared show full event" : "Khi được chia sẻ thì thể hiện đầy đủ sự kiện",
     "When shared show only busy" : "Khi được chia sẻ thì chỉ thể hiện đang bận",
     "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
     "Canceled" : "Đã bị hủy",
+    "All day" : "Cả ngày",
+    "Details" : "Chi tiết",
+    "Select tags" : "Chọn một thẻ",
+    "Notes" : "Ghi chú",
     "Mark as done" : "Đánh dấu là đã hoàn thành",
     "An error occurred" : "Có lỗi đã xảy ra",
     "Message from {author} in {conversationName}" : "Tin nhắn từ {author} trong {conversationName}"
