@@ -85,6 +85,9 @@ OC.L10N.register(
     "Before the task is due" : "任务截止前",
     "Select date and time" : "选择日期和时间",
     "Go back" : "返回",
+    "Do you want to keep related reminders?" : "是否要保留相关提醒？",
+    "Discard reminders" : "舍弃提醒",
+    "Keep reminders" : "保留提醒",
     "Set a reminder relative to your tasks start date:" : "设置与任务开始日期相关的提醒：",
     "Set a reminder relative to your tasks due date:" : "设置与任务截止日期相关的提醒：",
     "before at" : "在此之前：",
@@ -253,7 +256,7 @@ OC.L10N.register(
     "Could not delete the task." : "无法删除任务。",
     "Synchronizing to the server." : "正在同步到服务器。",
     "Task successfully saved to server." : "任务已成功保存到服务器。",
-    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "无法更新任务，因为它已在服务器上被更改。请点击以刷新此任务，本地变更将被丢弃。",
+    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "无法更新任务，因为它已在服务器上更改。请点击刷新，本地更改将被舍弃。",
     "Could not update the task." : "无法更新任务。",
     "Successfully updated the task." : "成功更新任务。",
     "Task successfully moved to new calendar." : "任务已成功移至新日历。",
