@@ -85,6 +85,9 @@ OC.L10N.register(
     "Before the task is due" : "任務截止前",
     "Select date and time" : "選取日期與時間",
     "Go back" : "返回",
+    "Do you want to keep related reminders?" : "您是否要保留相關提醒事項？",
+    "Discard reminders" : "捨棄提醒",
+    "Keep reminders" : "保留提醒",
     "Set a reminder relative to your tasks start date:" : "設定與您的任務開始日期相關的提醒：",
     "Set a reminder relative to your tasks due date:" : "設定與您的任務截止日期相關的提醒：",
     "before at" : "之前於",
